Package 'cells'

Title: Grid Logic
Description: Grid logic for rasters. Grid logic involves a rectangular extent and a 'grain', the discretization of that extent into rectangular cells. This logic exists in several packages but here is intended to be completely independent of data usage.
Authors: Michael D. Sumner [aut, cre] (ORCID: <https://orcid.org/0000-0002-2471-7511>)
Maintainer: Michael D. Sumner <[email protected]>
License: GPL-3
Version: 0.0.0.9000
Built: 2026-05-15 06:31:39 UTC
Source: https://github.com/hypertidy/cells

Help Index